#include <SPI.h>

//Setting up and initializing the display
#include <Adafruit_GFX.h>
#include <Adafruit_RA8875.h>

#define RA8875_INT 3
#define RA8875_CS 10
#define RA8875_RESET 9

Adafruit_RA8875 tft = Adafruit_RA8875(RA8875_CS, RA8875_RESET);
uint16_t tx, ty;

//Define some variables
float ballwidth = 0;
float velocitymph = 0;
float velocitymn = 0;
float velocitymps = 0;
unsigned long pulseResult = 0;
// Define the input ports we will be using
int ADC_Pin = A0;
int PhotoPin = 7;
// These are characters that will be displayed by the screen
char vel_value[6];


void setup()
{ 
  Serial.begin(115200);
  //define the 
  pinMode(PhotoPin, INPUT);
  
  /* Initialize the display using 'RA8875_480x80', 'RA8875_480x128', 'RA8875_480x272' or 'RA8875_800x480' */
  if (!tft.begin(RA8875_800x480)) {
    Serial.println("RA8875 Not Found!");
    while (1);
  }

  //More stuff that is setting up the display
  tft.displayOn(true);
  tft.GPIOX(true);      // Enable TFT - display enable tied to GPIOX
  tft.PWM1config(true, RA8875_PWM_CLK_DIV1024); // PWM output for backlight
  tft.PWM1out(255);
  
  tft.fillScreen(RA8875_BLACK);
}

void loop()
//This program will search for a pulse width that is between 60 and 200 microseconds wide
//When a pulse is found, the program runs to find the velocity of the object (ping pong ball).
{
  noInterrupts();
  pulseResult = pulseIn(PhotoPin, HIGH, 100000000);
  interrupts();
  
  if (pulseResult>60 && pulseResult<200) {
    ballwidth = 0.0405; //Ball width in meters
    velocitymps = ballwidth * 1000000 / pulseResult; //Finds the velocity of the ball in m/s
    velocitymn = ballwidth * 1000000 / pulseResult / 343; //Finds the velocity of the ball in m/s
    velocitymph = ballwidth * 1000000 *2.237 / pulseResult; //Finds the velocity of the ball in m/s
    Serial.print("Velocity (m/s): ");
    Serial.println(velocitymps);
  printLCD();
  delay(5000);
  }
}


void printLCD()
{ 
  //fill the screen with black
  tft.fillScreen(RA8875_BLACK);
  tft.textMode();
  tft.textEnlarge(4);
  tft.textSetCursor(20, 30);
  
  //Set the text to be white
  tft.textTransparent(RA8875_WHITE);
  tft.textWrite("Velocity (m/s):");
  //Convert the velocity value to a string
  dtostrf(velocitymps, 3, 2, vel_value);
   //display the value
  tft.textWrite(vel_value);
  
  tft.textSetCursor(20, 170);

  tft.textWrite("Mach Number:");
  //Convert the velocity value to a string
  dtostrf(velocitymn, 3, 2, vel_value);
  //display the value
  tft.textWrite(vel_value);

  tft.textSetCursor(20, 310);

  tft.textWrite("Velocity (mi/h):");
  //Convert the velocity value to a string
  dtostrf(velocitymph, 3, 2, vel_value);
  //display the value
  tft.textWrite(vel_value);
}
